#!/bin/sh
#

progname=$0
version=0.1.0
usage="\
Usage: $progname
Read a word from standard input, and search for the word through specified DICT server.
See http://www.dict.org/ about DICT.
Show the search result on standard output.
Internally, call dict, dict.pl or def, which are DICT clients.
  -s, --server       {dict.org:2628}
                     specify a DICT server and port
  -h, --help         print this help and exit
  -v, --version      print version information and exit"

# DICT <http://www.dict.org/> clients
DICT=dict
DICT_PL=dict.pl
DEF=def

# Use one of DICT clients
X_DICT=
X_ARG=

# Default dict server and port
DICT_SERVER="dict.org"
DICT_PORT=2628

# Option processing
while [ "$1" != "" ]
do
	case "$1" in
	-s | --server) 
		shift
		test $# -eq 0 && { echo "$usage"; exit 0; }
		DICT_SERVER=`expr "$1" : '\([^:*]\)'`
		DICT_PORT=`expr "$1" : '[^:]*:\([0-9]*\)'`
		;;
	-h | --help) 
		echo "$usage"; exit 0;;
	-v | --version | --v*)
		echo "$progname $version"; exit 0;;
	--) # Stop option processing.
		shift; break ;;
	*)	
		break ;;
	esac
	shift	
done


# Determine what DICT clients to use
if [ -x $DICT ]; then
	X_DICT=$DICT
	X_ARG="-h $DICT_SERVER -p $DICT_PORT"
elif [ -x $DICT_PL ]; then
	X_DICT=$DICT_PL
	X_ARG="-s $DICT_SERVER:$DICT_PORT"
elif [ -x $DEF ]; then
	X_DICT=$DEF
	X_ARG="-H $DICT_SERVER -p $DICT_PORT"
else
	echo "Warning:"
	echo "Neither $DICT, $DICT_PL nor $DEF are executable."
	exit 0
fi

# target word from standard input
read target

# Search for the target word through DICT
$X_DICT $X_ARG $target

exit 0
